@@ -29,6 +29,13 @@
     return NULL; \
     }
 
+/*
+ * Externally implemented functions
+ */
+
+extern void _Billiard_setblocking(int fd, int blocking);
+extern ssize_t _Billiard_conn_send_offset(HANDLE fd, char *string, Py_ssize_t len, Py_ssize_t offset);
+
 /*
  * Allocation and deallocation
  */
@@ -378,6 +385,13 @@ Billiard_connection_send_obj(BilliardConnectionObject *self, PyObject *obj)
     return NULL;
 }
 
+static PyObject *
+Billiard_connection_setblocking(BilliardConnectionObject *self, PyObject *arg)
+{
+    _Billiard_setblocking((int)self->handle, PyInt_AS_LONG(arg));
+    Py_RETURN_NONE;
+}
+
 static PyObject *
 Billiard_connection_recv_payload(BilliardConnectionObject *self)
 {
